<?php
/**
 * taskup functions and definitions
 *
 * @link https://themeforest.net/user/amentotech/portfolio
 *
 * @package taskup
 */

if ( ! defined( 'THEME_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( 'THEME_VERSION', '1.0.0' );
}

if ( ! function_exists( 'taskup_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function taskup_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on taskup, use a find and replace
		 * to change 'taskup' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'taskup', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
				'primary-menu' 	=> esc_html__( 'Primary menu', 'taskup' ),
				'footer-menu' 	=> esc_html__( 'Footer menu', 'taskup' ),
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption'
			)
		);
		
		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );
		
		/*
		* Enable support for Post Formats.  
		* See http://codex.wordpress.org/Post_Formats
		*/
		add_theme_support('post-formats' , array (
			''
		));
		
		// Add support for responsive embedded content.
		add_theme_support( 'responsive-embeds' );

		// Add support for Block Styles.
		add_theme_support( 'wp-block-styles' );

		// Add support for full and wide align images.
		add_theme_support( 'align-wide' );

		// Add support for editor styles.
		add_theme_support( 'editor-styles' );
		// Add custom editor font sizes.

		add_theme_support(
			'editor-font-sizes',
			array(
				array(
					'name'      => esc_html__( 'Small', 'taskup' ),
					'size'      => 14,
					'slug'      => 'small',
				),
				array(
					'name'      => esc_html__( 'Normal', 'taskup' ),
					'size'      => 16,
					'slug'      => 'normal',
				),
				array(
					'name'      => esc_html__( 'Large', 'taskup' ),
					'size'      => 36,
					'slug'      => 'large',
				),
				array(
					'name'      => esc_html__( 'Extra Large', 'taskup' ),
					'size'      => 48,
					'slug'      => 'extra-large',
				),
			)
		);

		//theme default color 
		add_theme_support( 
			'editor-color-palette', array(
			array(
				'name' => esc_html__( 'Theme Color', 'taskup' ),
				'slug' => 'strong-theme-color',
				'color' => '#FCCF14',
			),
			array(
				'name' => esc_html__( 'Theme Light text color', 'taskup' ),
				'slug' => 'light-gray',
				'color' => '#676767',
			),
			array(
				'name' => esc_html__( 'Theme Very Light text color', 'taskup' ),
				'slug' => 'very-light-gray',
				'color' => '#eee',
			),
			array(
				'name' => esc_html__( 'Theme Dark text color', 'taskup' ),
				'slug' => 'very-dark-gray',
				'color' => '#0A0F26',
			),
		) );

		// Add support for woocommerce
		add_theme_support( 'woocommerce' );
		add_theme_support( 'wc-product-gallery-zoom' );
		add_theme_support( 'wc-product-gallery-lightbox' );
		add_theme_support( 'wc-product-gallery-slider' );
}
endif;
add_action( 'after_setup_theme', 'taskup_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
if(!function_exists('taskup_content_width')){
	function taskup_content_width() {
		$GLOBALS['content_width'] = apply_filters( 'taskup_content_width', 1296 );
	}
	add_action( 'after_setup_theme', 'taskup_content_width', 0 );
}

/**
 * Taskup paid theme.
 *
 * @global bolean $paid
 */
if(!function_exists('taskup_paid_theme')){
	function taskup_paid_theme($paid = 'free') {
		return 'paid';
	}
	add_filter( 'taskup_paid_theme', 'taskup_paid_theme', 10);
}

/**
 * Register widget area.
 *
 * @link https://themeforest.net/user/amentotech/portfolio
 */
if(!function_exists('taskup_widgets_init')){
	function taskup_widgets_init() {
				
		register_sidebar(
			array(
				'name'          => esc_html__( 'Default sidebar', 'taskup' ),
				'id'            => 'taskup-sidebar',
				'description'   => esc_html__( 'Default archive sidebar', 'taskup' ),
				'before_widget' => '<div id="%1$s" class="widget %2$s tk-widgetbox">',
				'after_widget'  => '</div>',
				'before_title'  => '<div class="tk-sidetitle"><h5>',
				'after_title'   => '</h5></div>',
			)
		);		
		register_sidebar(
			array(
				'name'          => esc_html__( 'Footer sidebar 1', 'taskup' ),
				'id'            => 'taskup-sidebar-f1',
				'description'   => esc_html__( 'For footer first section', 'taskup' ),
				'before_widget' => '<div id="%1$s" class="%2$s tk-widgetbox">',
				'after_widget'  => '</div>',
				'before_title'  => '<div class="tk-sidetitle"><h5>',
				'after_title'   => '</h5></div>',
			)
		);
		register_sidebar(
			array(
				'name'          => esc_html__( 'Footer sidebar 2', 'taskup' ),
				'id'            => 'taskup-sidebar-f2',
				'description'   => esc_html__( 'For footer second column', 'taskup' ),
				'before_widget' => '<div id="%1$s" class="%2$s tk-widgetbox">',
				'after_widget'  => '</div>',
				'before_title'  => '<div class="tk-sidetitle"><h5>',
				'after_title'   => '</h5></div>',
			)
		);
		
		register_sidebar(
			array(
				'name'          => esc_html__( 'Footer sidebar 3', 'taskup' ),
				'id'            => 'taskup-sidebar-f3',
				'description'   => esc_html__( 'For footer third column', 'taskup' ),
				'before_widget' => '<div id="%1$s" class="%2$s tk-widgetbox">',
				'after_widget'  => '</div>',
				'before_title'  => '<div class="tk-sidetitle"><h5>',
				'after_title'   => '</h5></div>',
			)
		);
	}
	add_action( 'widgets_init', 'taskup_widgets_init' );
}

/**
 * Enqueue scripts and styles.
 */
if(!function_exists('taskup_scripts')){
	function taskup_scripts() {
		global $taskbot_settings;
		$header_search		= !empty($taskbot_settings['header_search']) ? $taskbot_settings['header_search'] : false;
		$loading_duration	= !empty($taskbot_settings['loading_duration']) ? $taskbot_settings['loading_duration'] : 500;
		$theme_version 		= wp_get_theme('taskup');
		$taskup_custom_css	= '';
		
		//register css
		wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap.min.css', array(), $theme_version->get('Version'));
		wp_register_style( 'nouislider', get_template_directory_uri() . '/css/nouislider.min.css', array(), $theme_version->get('Version'),'all');
		wp_enqueue_style( 'taskbot-icons', get_template_directory_uri(). '/css/taskbot-icons.css', array(),$theme_version->get('Version'), 'all' );
		wp_enqueue_style( 'fontawesome', get_template_directory_uri(). '/css/fontawesome/all.min.css', array(), $theme_version->get('Version'), 'all' );
		wp_enqueue_style( 'taskup-style', get_stylesheet_uri(), array(), $theme_version->get('Version') );
		wp_enqueue_style( 'taskup-main', get_template_directory_uri(). '/css/main.css', array('taskup-style'), $theme_version->get('Version'), 'all' );
		wp_enqueue_style( 'select2', get_template_directory_uri() . '/css/select2.min.css',  array(), $theme_version->get('Version'));
		wp_enqueue_style( 'taskup-responsive', get_template_directory_uri() . '/css/responsive.css',  array(), $theme_version->get('Version'));

		//register js
		wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/js/vendor/bootstrap.min.js', array( 'jquery' ), $theme_version->get('Version'), true );
		wp_enqueue_script( 'nouislider', get_template_directory_uri() . '/js/vendor/nouislider.min.js', array( 'jquery' ), $theme_version->get('Version'), true );
		wp_enqueue_script( 'select2', get_template_directory_uri() . 'js/vendor/select2.min.js', array(), $theme_version->get('Version'), true );
		wp_enqueue_script( 'taskup-callbacks', get_template_directory_uri() . '/js/callbacks.js', array('jquery'), $theme_version->get('Version'), true );

		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

		if( is_page_template( 'templates/search-freelancer.php' ) ){
			wp_enqueue_style('nouislider');
            wp_enqueue_script('nouislider');
		}
		wp_localize_script('taskup-callbacks', 'taskup_vars', array(
			'loading_duration'			=> $loading_duration,
            'ajaxurl'					=> admin_url('admin-ajax.php'),
        ));
	}
	add_action( 'wp_enqueue_scripts', 'taskup_scripts' );
}

/**
 * @Enque Google Font
 * @return
 */
if (!function_exists('taskup_enqueue_google_fonts')) {
    function taskup_enqueue_google_fonts() {
		$protocol = is_ssl() ? 'https' : 'http';
		
		//Default theme font famlies
		$font_families	= array();
		$font_families[] = 'Urbanist:400,600,700,900';
		$font_families[] = 'Open+Sans:400,600,700';
		
		 $query_args = array (
			 'family' => implode('%7C' , $font_families) ,
			 'subset' => 'latin,latin-ext' ,
        );

        $theme_fonts = add_query_arg($query_args , $protocol.'://fonts.googleapis.com/css');

		wp_enqueue_style('taskbot-fonts-enqueue' , esc_url_raw($theme_fonts), array () , null);
    }
    add_action('wp_enqueue_scripts' , 'taskup_enqueue_google_fonts');
}

/**
 * Include files
 */
require get_template_directory() . '/inc/template-tags.php';
require get_template_directory() . '/inc/template-functions.php';
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}